{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for Metapost/Metafont.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/metafont.xml and 'make bootstrap'.
module Skylighting.Syntax.Metafont (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for Metapost/Metafont.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Metapost/Metafont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmetafont.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMetafont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Metapost/Metafont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO(FIXME|TODO):?\SOH\FS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\195\151\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bContrSeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bContrSeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Metapost/Metafont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQverb*\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Metapost/Metafont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTVerb\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1verb(?=[^a-zA-Z])\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Metapost/Metafont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTVerb\NUL\195\151\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN[a-zA-Z]+(\\+?|\\*{0,3})\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t[^a-zA-Z]\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMathContrSeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMathContrSeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Metapost/Metafont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\195\151\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f[a-zA-Z]+\\*?\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t[^a-zA-Z]\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMathMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMathMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Metapost/Metafont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX$$\FS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\\\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Metapost/Metafont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMathContrSeq\NUL$\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\\)\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\\]\FS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormal Text\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormal Text\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Metapost/Metafont\NUL\NUL\NUL\NUL\NUL\NUL\NUL,\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncharexists\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQknown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXodd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aunknown\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQangle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQascii\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aceiling\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcosd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdirectiontime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adotprod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfloor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXhex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rnormaldeviate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXoct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsind\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsqrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtotalweight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rturningnumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOuniformdeviate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxpart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKxxpart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKxypart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQypart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKyxpart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKyypart\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fautorounding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fboundarychar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcharcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKchardp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKchardx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKchardy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acharext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcharht\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcharic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcharwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXday\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndesignsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfillin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfontmaking\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgranularity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThppp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmonth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apausing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bproofing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fshowstopping\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsmoothing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SItracingcapsules\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtracingchoices\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SItracingcommands\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftracingedges\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEtracingequations\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtracingmacros\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtracingonline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtracingoutput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtracingpens\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SItracingrestores\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftracingspecs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftracingstats\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtracingtitles\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fturningcheck\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTvppp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fwarningcheck\NUL\NUL\NUL\NUL\NUL\NUL\NUL\axoffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTyear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ayoffset\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpenoffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vpostcontrol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nprecontrol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arotated\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKscaled\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ashifted\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aslanted\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtransformed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\axscaled\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ayscaled\NUL\NUL\NUL\NUL\NUL\NUL\NUL\azscaled\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aatleast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontrols\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcurl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcycle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmakepath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asubpath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atension\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amakepen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anullpen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpencircle\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vnullpicture\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTchar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adecimal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ajobname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nreadstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXstr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsubstring\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQaddto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTalso\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tbatchmode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acontour\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndelimiters\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adisplay\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndoublepath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdropping\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdump\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aerrhelp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nerrmessage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rerrorstopmode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\beveryjob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfrom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainterim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\binwindow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\akeeping\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amessage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vnewinternal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vnonstopmode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nnumspecial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nopenwindow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQouter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nrandomseed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsave\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nscrollmode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ashipout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTshow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEshowdependencies\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tshowstats\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tshowtoken\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fshowvariable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aspecial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\awithpen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nwithweight\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aboolean\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anumeric\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpair\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apicture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttransform\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexpr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aprimary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nprimarydef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsecondary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsecondarydef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsuffix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btertiary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtertiarydef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtext\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKelseif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexitif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTstep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuntil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTupto\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcharlist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bendinput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vexpandafter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nextensible\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfontdimen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nheaderbyte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQinner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQinput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1intersectiontimes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTkern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bligtable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQquote\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nscantokens\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKskipto\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\172\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4addto_currentpicture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\faspect_ratio\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tbase_name\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fbase_version\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ablacker\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fblankpicture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbye\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbyte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcapsule_def\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fchange_width\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEclear_pen_memory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aclearit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bclearpen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aclearxy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcounterclockwise\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bculldraw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcullit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncurrentpen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcurrentpen_path\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcurrentpicture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcurrenttransform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcurrentwindow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acutdraw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcutoff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdecr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKdefine_blacker_pixels\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBdefine_corrected_pixels\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4define_good_x_pixels\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4define_good_y_pixels\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"define_horizontal_corrected_pixels\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdefine_pixels\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCdefine_whole_blacker_pixels\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3define_whole_pixels\NUL\NUL\NUL\NUL\NUL\NUL\NUL$define_whole_vertical_blacker_pixels\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSdefine_whole_vertical_pixels\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOdirectionpoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndisplaying\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQditto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdownto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdraw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adrawdot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXeps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aepsilon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQerase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nexitunless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vextra_setup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfilldraw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfix_units\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTflex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2font_coding_scheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEfont_extra_space\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIfont_identifier\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2font_normal_shrink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1font_normal_space\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3font_normal_stretch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfont_quad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfont_setup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfont_size\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfont_slant\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rfont_x_height\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfullcircle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgenerate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tgfcorners\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgobble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agobbled\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgrayfont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nhalfcircle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThide\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKhround\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bidentity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vimage_rules\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTincr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\binfinity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\binteract\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tinterpath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1intersectionpoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bitalcorr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vjoin_radius\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkilltext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlabelfont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlabels\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTleft\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlft\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlocalfont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nloggingall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlowres\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlowres_fix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amagstep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amakebox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmakegrid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmakelabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmaketicks\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmode_def\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmode_name\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmode_setup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nnodisplays\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fnotransforms\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SInumber_of_modes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnumtok\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fo_correction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKopenit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKorigin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apen_bot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apen_lft\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpen_rt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apen_top\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpenlabels\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpenpos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpenrazor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpenspeck\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpensquare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpenstroke\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpickup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIpixels_per_inch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQproof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vproofoffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tproofrule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2proofrulethickness\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rquartercircle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOreflectedabout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrelax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQright\NUL\NUL\NUL\NUL\NUL\NUL\NUL\frotatedabout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rrotatedaround\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQround\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arulepen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asavepen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vscreen_cols\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vscreen_rows\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vscreenchars\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nscreenrule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rscreenstrokes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKshipit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKshowit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tslantfont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsmode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsmoke\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsoftjoin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsolve\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTstop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsuperellipse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttakepower\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttensepath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttitlefont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttolerance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntracingall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtracingnone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKundraw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tundrawdot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunfill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nunfilldraw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tunitpixel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nunitsquare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nunitvector\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTupto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvround\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bwhatever\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbluepart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTclip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdashed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfontsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tgreenpart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinfont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alinecap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blinejoin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bllcorner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blrcorner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmiterlimit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmpxbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprologues\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aredpart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsetbounds\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEtracinglostchars\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtruecorners\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bulcorner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\burcorner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\twithcolor\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\201\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aahangle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bahlength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tarrowhead\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nbackground\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tbase_name\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fbase_version\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbbox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nbboxmargin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abeveled\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQblack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ablacker\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fblankpicture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTblue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQboxit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aboxjoin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbpath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nbuildcycle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbutt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbye\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbyte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcapsule_def\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcenter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fchange_width\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcircleit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncircmargin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEclear_pen_memory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aclearit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bclearpen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aclearxy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcounterclockwise\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcullit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncurrentpen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcurrentpen_path\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcurrentpicture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcurrenttransform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcutafter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcutbefore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acutdraw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcuttings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdashpattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdecr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdefaultdx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdefaultdy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdefaultfont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndefaultpen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fdefaultscale\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKdefine_blacker_pixels\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBdefine_corrected_pixels\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4define_good_x_pixels\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4define_good_y_pixels\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"define_horizontal_corrected_pixels\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdefine_pixels\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCdefine_whole_blacker_pixels\NUL\NUL\NUL\NUL\NUL\NUL\NUL$define_whole_vertical_blacker_pixels\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSdefine_whole_vertical_pixels\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOdirectionpoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQditto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdotlabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdotlabels\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdownto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdraw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdrawarrow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdrawboxed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdrawboxes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fdrawdblarrow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adrawdot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdrawoptions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdrawunboxed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXeof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXeps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aepsilon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQerase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKevenly\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nexitunless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vextra_setup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfilldraw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfixpos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afixsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTflex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2font_coding_scheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEfont_extra_space\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIfont_identifier\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2font_normal_shrink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1font_normal_space\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3font_normal_stretch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfont_quad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfont_size\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfont_slant\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rfont_x_height\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfullcircle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tgfcorners\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgobble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agobbled\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgrayfont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQgreen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nhalfcircle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThide\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKhround\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bidentity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQimage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nimagerules\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTincr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\binfinity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\binteract\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tinterpath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1intersectionpoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bitalcorr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlabelfont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vlabeloffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlabels\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTleft\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlft\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTllft\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nloggingall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlowres_fix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amagstep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amakebox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmakegrid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmakelabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmaketicks\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amitered\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmode_def\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmode_setup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nnodisplays\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fnotransforms\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOnumeric_pickup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnumtok\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fo_correction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKopenit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKorigin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apen_bot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apen_lft\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpen_rt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apen_top\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpenlabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpenpos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpenrazor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpenspeck\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpensquare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpenstroke\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpickup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vproofoffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tproofrule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2proofrulethickness\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rquartercircle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXred\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOreflectedabout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrelax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQright\NUL\NUL\NUL\NUL\NUL\NUL\NUL\frotatedabout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rrotatedaround\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQround\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arounded\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arulepen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asavepen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vscreenchars\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nscreenrule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rscreenstrokes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKshipit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKshowit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tslantfont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsmode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsoftjoin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsolve\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asquared\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTstop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsuperellipse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttakepower\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttensepath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bthelabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTthru\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttitlefont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntracingall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtracingnone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTulft\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKundraw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tundrawdot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunfill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nunfilldraw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tunitpixel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nunitsquare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nunitvector\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTupto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXurt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvround\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bwhatever\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bwithdots\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL%\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Metapost/Metafont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Metapost/Metafont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK(\\+|\\-|\\*|\\/|\\=|\\:\\=)\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH..\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\\b(bp|cc|cm|dd|in|mm|pc|pt)\\b\SOH\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\\b-?\\d+(bp|cc|cm|dd|in|mm|pc|pt)#?\\b\SOH\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL&\\b-?\\.\\d+(bp|cc|cm|dd|in|mm|pc|pt)#?\\b\SOH\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL)\\b-?\\d+\\.\\d+(bp|cc|cm|dd|in|mm|pc|pt)#?\\b\SOH\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\\b[xy]\\d(\\w|\\')*\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\\bz\\d(\\w|\\')*\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\\bp\\d(\\w|\\')*\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\\b(verbatimtex|btex)\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Metapost/Metafont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aTeXMode\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EM\\bbegin(group|fig|char)\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\\bend(group|fig|char)\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\\bextra_begin(group|fig|char)\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\\bextra_end(group|fig|char)\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\\b(def|vardef)\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\benddef\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\bif\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\bfi\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\\b(for|forsuffixes|forever)\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\bendfor\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aTeXMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aTeXMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Metapost/Metafont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\\\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Metapost/Metafont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bContrSeq\NUL$\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Metapost/Metafont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMathMode\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\\(\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Metapost/Metafont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMathMode\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\betex\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vToEndOfLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vToEndOfLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Metapost/Metafont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTVerb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTVerb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Metapost/Metafont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX(.)\SOH\RS\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Metapost/Metafont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVerbEnd\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVerbEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVerbEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Metapost/Metafont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX%1\RS\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\195\151\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n[^%1\\xd7]*\SOH\RS\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Metapost/Metafont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DC1\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\\\\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSYedvilun (yedvilun@gmail.com)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLGPL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.mp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.mps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a*.mpost\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.mf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormal Text"
