{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for Lua.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/lua.xml and 'make bootstrap'.
module Skylighting.Syntax.Lua (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for Lua.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alua.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rBlock Comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rBlock Comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\]%1\\]\SOH\f\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH--\FS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !\"%&()*+,-/:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFIXME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTNOTE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTODO\FS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SOH--\FS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !\"%&()*+,-/:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFIXME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTNOTE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTODO\FS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDoxygenLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !\"%&()*+,-/:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aforeach\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bforeachi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtable.foreach\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtable.foreachi\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n--\\[(=*)\\[\SOH\f\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rBlock Comment\SOH--\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\[(=*)\\[\SOH\b\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fString_block\NUL'\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rString_single\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rString_double\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !\"%&()*+,-/:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\251\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLUA_PATH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK_ALERT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r_ERRORMESSAGE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a_LOADED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b_VERSION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTacos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bappendto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQascii\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTasin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKassert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTatan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQatan2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTceil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcgilua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBcgilua.addclosefunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNcgilua.addopenfunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBcgilua.addscripthandler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBcgilua.buildprocesshandler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4cgilua.contentheader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcgilua.cookies\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKcgilua.cookies.delete\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2cgilua.cookies.get\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2cgilua.cookies.set\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNcgilua.cookies.sethtml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcgilua.doif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcgilua.doscript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcgilua.errorlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcgilua.handlelp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcgilua.header\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1cgilua.htmlheader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1cgilua.lp.compile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1cgilua.lp.include\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBcgilua.lp.setcompatmode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4cgilua.lp.setoutfunc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3cgilua.lp.translate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4cgilua.mkabsoluteurl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcgilua.mkurlpath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcgilua.pack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncgilua.put\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcgilua.redirect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2cgilua.script_file\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2cgilua.script_path\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2cgilua.script_pdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2cgilua.script_vdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3cgilua.script_vpath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcgilua.serialize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKcgilua.servervariable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcgilua.session\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4cgilua.session.close\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3cgilua.session.data\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKcgilua.session.delete\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3cgilua.session.load\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2cgilua.session.new\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3cgilua.session.open\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3cgilua.session.save\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FScgilua.session.setsessiondir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNcgilua.seterrorhandler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKcgilua.seterroroutput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKcgilua.setmaxfilesize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2cgilua.setmaxinput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1cgilua.setoutfunc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcgilua.splitpath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBcgilua.urlcode.encodetable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKcgilua.urlcode.escape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBcgilua.urlcode.insertfield\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMcgilua.urlcode.parsequery\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBcgilua.urlcode.unescape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcgilua.urlpath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tclosefile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcollectgarbage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcommit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aconnect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcopytagmethods\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdebug.gethook\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdebug.getinfo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOdebug.getlocal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdebug.sethook\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOdebug.setlocal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdeg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdofile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdostring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQerror\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aexecute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfetch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfiles\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfloor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQflush\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aforeach\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bforeachi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKformat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfrexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgcinfo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgetcolnames\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgetcoltypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgetenv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tgetglobal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ngetglobals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agetinfo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgetlocal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgetmetatable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgetn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgettagmethod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aglobals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgsub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bio.close\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bio.flush\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bio.input\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bio.lines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aio.open\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tio.output\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aio.read\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tio.stderr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bio.stdin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tio.stdout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nio.tmpfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bio.write\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKipairs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQldexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlfs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOlfs.attributes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlfs.chdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOlfs.currentdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alfs.dir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blfs.lock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlfs.mkdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlfs.rmdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlfs.touch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlfs.unlock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bloadfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nloadstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlog10\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmath.abs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmath.acos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmath.asin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmath.atan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmath.atan2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmath.ceil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmath.cos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmath.deg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmath.exp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmath.floor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmath.frexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmath.ldexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmath.log\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmath.log10\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmath.max\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmath.min\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmath.mod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmath.rad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmath.random\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SImath.randomseed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmath.sin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmath.squrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmath.tan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnewtag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anumrows\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bopenfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bos.clock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aos.date\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vos.difftime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nos.execute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aos.exit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tos.getenv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tos.remove\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tos.rename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fos.setlocale\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aos.time\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nos.tmpname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpairs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpcall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrandom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nrandomseed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrawget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrawset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breadfrom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKremove\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arequire\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brollback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTseek\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsetautocommit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsetcallhook\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsetglobal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsetglobals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsetlinehook\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsetlocal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsetlocale\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsetmetatable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsettag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsettagmethod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsqurt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\astrbyte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\astrchar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\astrfind\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vstring.byte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vstring.char\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vstring.find\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rstring.format\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstring.gfind\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vstring.gsub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nstring.len\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstring.lower\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nstring.rep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nstring.sub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstring.upper\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstrlen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bstrlower\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstrrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstrsub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bstrupper\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftable.concat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtable.foreach\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtable.foreachi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntable.getn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftable.insert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftable.remove\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntable.setn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntable.sort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atinsert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atmpname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btonumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btostring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atremove\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunpack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwrite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\awriteto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXzip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bzip.open\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fzip.openfile\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\\bfunction\\b\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !\"%&()*+,-/:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlocal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXor\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !\"%&()*+,-/:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrue\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\belse\\b\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\belseif\\b\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\bdo\\b\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\bif\\b\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\bend\\b\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !\"%&()*+,-/:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKelseif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrepeat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTthen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuntil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\\b\\d*\\.?\\d*(e|e\\-|e\\+)?\\d+\\b\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\\b-?0[xX][0-9a-fA-F]+\\b\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL.\\b[a-zA-Z_][a-zA-Z0-9_]*(?=\\s*([({'\"]|\\[\\[))\\b\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4\\b[A-Z_][A-Z0-9_]*\\b\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB\\b[a-zA-Z_][a-zA-Z0-9_]*\\b\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH!=\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH-=\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH+=\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH++\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.=\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1[]().,=~+-*/^><#;\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fString_block\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fString_block\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\\\\(a|b|f|n|r|t|v|\\\\|\"|\\'|[|])\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\]%1\\]\SOH\b\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rString_double\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rString_double\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3\\\\[abfnrtv'\"\\\\\\[\\]]\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rString_single\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rString_single\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\\\\(a|b|f|n|r|t|v|\\\\|\"|\\'|[|])\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.lua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal"
