{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for Alerts.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/alert.xml and 'make bootstrap'.
module Skylighting.Syntax.Alert (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for Alerts.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAlerts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\talert.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQAlert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormal Text\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormal Text\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAlerts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX{{{\EM\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX}}}\EM\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBEGIN\EM\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXEND\EM\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQALERT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tATTENTION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDANGER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTHACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSECURITY\FS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXBUG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCAUTION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDEPRECATED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFIXME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNOLINT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTASK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXTBD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTODO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aWARNING\FS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX###\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTNOTE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNOTICE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTEST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aTESTING\FS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSDominik Haumann (dhdev@gmx.de)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aLGPLv2+\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormal Text"
