{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for Modula-3.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/modula-3.xml and 'make bootstrap'.
module Skylighting.Syntax.Modula3 (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for Modula-3.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmodula-3.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aModula3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComment2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComment2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SOH(*\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComment2\SOH*)\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1PROCEDURE[\\s].*\\(\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSEND\\s*[A-Za-z][A-Za-z0-9_]*\\;\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL:\\b(RECORD|OBJECT|TRY|WHILE|FOR|REPEAT|LOOP|IF|CASE|WITH)\\b\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\b(END;|END)\\b\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !%&()*+,-/:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXANY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQARRAY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXAS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBEGIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBITS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBRANDED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXBY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCASE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCONST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXDO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTELSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQELSIF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXEND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTEVAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKEXCEPT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tEXCEPTION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTEXIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aEXPORTS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aFINALLY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXFOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTFROM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aGENERIC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKIMPORT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tINTERFACE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLOCK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLOOP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aMETHODS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMODULE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKOBJECT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXOF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tOVERRIDES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPROCEDURE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRAISE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRAISES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bREADONLY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRECORD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXREF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKREPEAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRETURN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKREVEAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTROOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTHEN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXTO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXTRY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTYPE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTYPECASE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKUNSAFE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQUNTIL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bUNTRACED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQVALUE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXVAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQWHILE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTWITH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !%&()*+,-/:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH#\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH&\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH(\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH+\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH,\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH-\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX..\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH/\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX:=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH;\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH<\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX<:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX<=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX=>\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH>\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX>=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDIV\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMOD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH[\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH]\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH^\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH{\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH|\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH}\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !%&()*+,-/:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aADDRESS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBOOLEAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCARDINAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCHAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bEXTENDED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aINTEGER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLONGREAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQMUTEX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTNULL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTREAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKREFANY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTEXT\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !%&()*+,-/:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFALSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNIL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTRUE\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !%&()*+,-/:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXABS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXADR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aADRSIZE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBITSIZE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bBYTESIZE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCEILING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDEC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDISPOSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFIRST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFLOAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFLOOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXINC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKISTYPE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLAST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLOOPHOLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMAX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNARROW\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNEW\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNUMBER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXORD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQROUND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSUBARRAY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQTRUNC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTYPECODE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXVAL\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !%&()*+,-/:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NULh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tEnv.Count\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aEnv.Get\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nEnv.GetNth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXFmt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFmt.Bool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFmt.Char\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFmt.Extended\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFmt.F\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKFmt.FN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aFmt.Int\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFmt.LongReal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aFmt.Pad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFmt.Real\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFmt.Unsigned\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKIO.EOF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nIO.GetChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIO.GetInt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nIO.GetLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nIO.GetReal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOIO.GetWideChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vIO.OpenRead\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fIO.OpenWrite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKIO.Put\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nIO.PutChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIO.PutInt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nIO.PutReal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOIO.PutWideChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLex.Bool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fLex.Extended\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aLex.Int\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fLex.LongReal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLex.Match\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLex.Real\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLex.Scan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLex.Skip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fLex.Unsigned\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKParams\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fParams.Count\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nParams.Get\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXRd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRd.CharsReady\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bRd.Close\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRd.Closed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRd.EOF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nRd.GetChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nRd.GetLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRd.GetSub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRd.GetSubLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nRd.GetText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORd.GetWideChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORd.GetWideLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRd.GetWideSub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Rd.GetWideSubLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORd.GetWideText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bRd.Index\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRd.Intermittend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRd.Length\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aRd.Seek\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vRd.Seekable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRd.UnGetChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTScan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tScan.Bool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rScan.Extended\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bScan.Int\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rScan.LongReal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tScan.Real\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rScan.Unsigned\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bText.Cat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fText.Compare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nText.Empty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nText.Equal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rText.FindChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOText.FindCharR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Text.FindWideChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Text.FindWideCharR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOText.FromChars\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Text.FromWideChars\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fText.GetChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEText.GetWideChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEText.HasWideChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tText.Hash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vText.Length\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rText.SetChars\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Text.SetWideChars\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bText.Sub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXWr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vWr.Buffered\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bWr.Close\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tWr.Closed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bWr.Flush\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bWr.Index\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tWr.Length\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nWr.PutChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fWr.PutString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nWr.PutText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOWr.PutWideChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEWr.PutWideString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOWr.PutWideText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aWr.Seek\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vWr.Seekable\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULM\\b[\\+|\\-]{0,1}[0-9]{1,}\\.[0-9]{1,}([E|e|D|d|X|x][\\+|\\-]{0,1}[0-9]{1,}){0,1}\\b\SOH\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL;\\b([\\+|\\-]{0,1}[0-9]{1,}|([2-9]|1[0-6])\\_[0-9A-Fa-f]{1,})\\b\SOH\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aString1\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\\'(.|\\\\[ntrf\\\\'\"]|\\\\[0-7]{3})\\'\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH<*\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPrep1\SOH(*\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComment2\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPrep1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPrep1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH*>\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aString1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aString1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT1.01\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLGPL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.m3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.i3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.ig\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.mg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal"
