{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for RelaxNG-Compact.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/relaxngcompact.xml and 'make bootstrap'.
module Skylighting.Syntax.Relaxngcompact (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for RelaxNG-Compact.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRelaxNG-Compact\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2relaxngcompact.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORelaxngcompact\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRelaxNG-Compact\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDefinitions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDefinitions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRelaxNG-Compact\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL=\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNode Names\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNode Names\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRelaxNG-Compact\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL{\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormal Text\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormal Text\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRelaxNG-Compact\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL#\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRelaxNG-Compact\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRelaxNG-Compact\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB\t\n !%&()*+,./;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdatatypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adefault\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQempty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bexternal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agrammar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainclude\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainherit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmixed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnamespace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nnotAllowed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKparent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtoken\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB\t\n !%&()*+,./;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tattribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aelement\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRelaxNG-Compact\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNode Names\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB\t\n !%&()*+,./;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL.\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fxsd:ENTITIES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nxsd:ENTITY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKxsd:ID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txsd:IDREF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nxsd:IDREFS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nxsd:NCName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vxsd:NMTOKEN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fxsd:NMTOKENS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fxsd:NOTATION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxsd:Name\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txsd:QName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nxsd:anyURI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLExsd:base64Binary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vxsd:boolean\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxsd:byte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxsd:date\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fxsd:dateTime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vxsd:decimal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nxsd:double\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fxsd:duration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txsd:float\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxsd:gDay\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nxsd:gMonth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rxsd:gMonthDay\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txsd:gYear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOxsd:gYearMonth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rxsd:hexBinary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\axsd:int\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vxsd:integer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fxsd:language\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxsd:long\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3xsd:negativeInteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNxsd:nonNegativeInteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNxsd:nonPositiveInteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4xsd:normalizedString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3xsd:positiveInteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txsd:short\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nxsd:string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxsd:time\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txsd:token\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLExsd:unsignedByte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIxsd:unsignedInt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLExsd:unsignedLong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1xsd:unsignedShort\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO[\\w\\.-]+[\\s]+=\SOH\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRelaxNG-Compact\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDefinitions\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRelaxNG-Compact\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRintze Zelle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLGPL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.rnc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormal Text"
