{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for GNU Assembler.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/gnuassembler.xml and 'make bootstrap'.
module Skylighting.Syntax.Gnuassembler (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for GNU Assembler.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGNU Assembler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgnuassembler.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fGnuassembler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommentar 1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommentar 1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGNU Assembler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAlerts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH*/\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommentar 2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommentar 2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGNU Assembler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAlerts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDefine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDefine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGNU Assembler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SO\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGNU Assembler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r[_\\w\\d-]*\\s*:\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !%&()*+,-/:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\184\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.abort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.align\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t.app-file\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b.appline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.arm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.ascii\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.asciz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v.att_syntax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.balign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b.balignl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b.balignw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.bss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.byte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.code\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.code16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.code32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.comm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.common\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t.common.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.data\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX.dc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.dc.b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.dc.d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.dc.l\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.dc.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.dc.w\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.dc.x\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.dcb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.dcb.b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.dcb.d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.dcb.l\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.dcb.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.dcb.w\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.dcb.x\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.debug\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.def\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.desc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.dim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.double\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX.ds\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.ds.b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.ds.d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.ds.l\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.ds.p\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.ds.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.ds.w\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.ds.x\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.dsect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.eject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.else\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.elsec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.elseif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.end\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.endc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.endef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b.endfunc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.endif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.endm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.endr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.equ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.equiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.err\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.even\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.exitm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.extend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.extern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.fail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.file\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.fill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.float\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f.force_thumb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.format\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.func\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.global\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.globl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.hidden\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.hword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.ident\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX.if\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.ifc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.ifdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.ifeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.ifeqs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.ifge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.ifgt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.ifle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.iflt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.ifnc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.ifndef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.ifne\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.ifnes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t.ifnotdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b.include\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.int\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r.intel_syntax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t.internal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.irep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.irepc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.irp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.irpc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.lcomm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b.ldouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.lflags\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.line\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t.linkonce\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.list\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.llen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX.ln\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.loc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.long\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.lsym\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.ltorg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.macro\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.mexit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.name\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t.noformat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.nolist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.nopage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.octa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.offset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.org\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b.p2align\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t.p2alignl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t.p2alignw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.packed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.page\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.plen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.pool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v.popsection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t.previous\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.print\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n.protected\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.psize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.purgem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f.pushsection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.quad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.rep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.rept\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.req\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.rodata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.rva\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.sbttl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.scl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.sect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.sect.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b.section\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n.section.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.set\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.short\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.single\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.size\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.skip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b.sleb128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.space\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.spc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.stabd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.stabn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.stabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.struct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v.subsection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.symver\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.tag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.text\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.thumb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v.thumb_func\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n.thumb_set\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.title\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.ttl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.type\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b.uleb128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.use\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.val\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b.version\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r.vtable_entry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI.vtable_inherit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.weak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.word\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.xcom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.xdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.xref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.xstabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.zero\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnoprefix\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n0[bB][01]+\SOH\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL-0[fFeEdD][-+]?[0-9]*\\.?[0-9]*[eE]?[-+]?[0-9]+\SOH\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB[A-Za-z_.$][A-Za-z0-9_.$]*\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL8'(\\\\x[0-9a-fA-F][0-9a-fA-F]?|\\\\[0-7]?[0-7]?[0-7]?|\\\\.|.)\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGNU Assembler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS#\\s*if(?:def|ndef)?(?=\\s+\\S)\NUL\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGNU Assembler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPreprocessor\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t#\\s*endif\NUL\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGNU Assembler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPreprocessor\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4#\\s*define.*((?=\\\\))\NUL\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGNU Assembler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDefine\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULL#\\s*(?:el(?:se|if)|include(?:_next)?|define|undef|line|error|warning|pragma)\SOH\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGNU Assembler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPreprocessor\SOH/*\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGNU Assembler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommentar 1\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX@;#\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGNU Assembler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommentar 2\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB!#%&*()+,-<=>?/:[]^{|}~\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPreprocessor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPreprocessor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGNU Assembler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSome Context\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSome Context\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGNU Assembler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGNU Assembler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SO\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGNU Assembler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSome Context\f\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NULnJohn Zaitseff (J.Zaitseff@zap.org.au), Roland Pabel (roland@pabel.name), Miquel Sabat\195\169 (mikisabate@gmail.com)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKGPLv2+\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX*.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX*.S\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal"
