{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for ASN.1.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/asn1.xml and 'make bootstrap'.
module Skylighting.Syntax.Asn1 (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for ASN.1.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQASN.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\basn1.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTAsn1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQASN.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormal Text\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormal Text\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQASN.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAPPLICATION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBEGIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDEFAULT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDEFINITIONS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXEND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aEXPORTS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFALSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTFROM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aIMPORTS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bOPTIONAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPRIVATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTRUE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tUNIVERSAL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBOOLEAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCHOICE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nENUMERATED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aINTEGER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTNULL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fOCTET STRING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXOF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTREAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSEQUENCE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vStringStore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rVisibleString\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH--\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQASN.1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEPhilippe Rigault\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXGPL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.asn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK*.asn1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormal Text"
