{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for Modula-2.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/modula-2.xml and 'make bootstrap'.
module Skylighting.Syntax.Modula2 (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for Modula-2.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmodula-2.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aModula2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComment2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComment2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH*)\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComment3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComment3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL@\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXABS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQARRAY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXASM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBEGIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBITSET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXBY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXCAP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCASE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXCHR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCONST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDEC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDEFINITION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDIV\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXDO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTELSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQELSIF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXEND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTEXCL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTEXIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKEXPORT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFALSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXFOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aFOREIGN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTFROM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTHALT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTHIGH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOIMPLEMENTATION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKIMPORT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXINC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTINCL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nIOTRANSFER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLOOP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMAX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMOD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMODULE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNEWPROCESS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNIL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXODD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXOF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXORD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPROC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPROCEDURE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tQUALIFIED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRECORD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKREPEAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRETURN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTHEN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXTO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTRANSFER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTRUE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQTRUNC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTYPE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQUNTIL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXVAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXVAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQWHILE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTWITH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL9\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bALLOCATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tASSEMBLER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nAccessible\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAppend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAssign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCAPS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQClose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKConcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCopy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDEALLOCATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDelete\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXEOF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vEmptyString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQErase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aGetArgs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aGetCard\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aGetChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKGetEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKGetInt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vGetLongReal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aGetReal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tGetString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKInsert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTOpen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tOpenInput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nOpenOutput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPutBf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPutCard\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPutChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPutInt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPutLn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPutLongReal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPutReal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPutString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRead\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bReadCard\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aReadInt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fReadLongReal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bReadReal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nReadString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nResetClock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSIZE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQStrEq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSystemTime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bUserTime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQWrite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aWriteBf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tWriteCard\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bWriteInt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aWriteLn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rWriteLongReal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tWriteReal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vWriteString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acompare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpos\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aADDRESS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXADR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBOOLEAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCARDINAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCHAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aINTEGER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aLONGINT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLONGREAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPOINTER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTREAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSHORTCARD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSHORTINT\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aString1\NUL'\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aString2\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX(*$\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPrep1\SOH(*\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComment2\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPrep1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPrep1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$*)\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPrep1\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aString1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aString1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aString2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aString2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL'\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.mod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.def\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.mi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.md\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal"
