{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for Erlang.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/erlang.xml and 'make bootstrap'.
module Skylighting.Syntax.Erlang (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for Erlang.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKErlang\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nerlang.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKErlang\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormal Text\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormal Text\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKErlang\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULT(?:-module|-export|-define|-undef|-ifdef|-ifndef|-else|-endif|-include|-include_lib)\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQafter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ball_true\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbegin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfun\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQquery\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areceive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsome_true\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTband\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbsl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbsr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbxor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXxor\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL7(?:\\+|-|\\*|\\/|==|\\/=|=:=|=\\/=|<|=<|>|>=|\\+\\+|--|=|!|<-)\SOH\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NULX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaccept\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQalarm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQapply\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fatom_to_list\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SObinary_to_list\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SObinary_to_term\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2check_process_code\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rconcat_binary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdelete_module\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIdisconnect_node\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aelement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQerase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rfloat_to_list\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgarbage_collect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bget_keys\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgroup_leader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThalt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXhd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIinteger_to_list\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bis_alive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ais_atom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tis_binary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nis_boolean\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bis_float\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vis_function\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nis_integer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ais_list\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tis_number\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKis_pid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ais_port\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEis_process_alive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tis_record\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fis_reference\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bis_tuple\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\flist_to_atom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOlist_to_binary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rlist_to_float\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIlist_to_integer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vlist_to_pid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rlist_to_tuple\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vload_module\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKloaded\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlocaltime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmake_ref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rmodule_loaded\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnodes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\topen_port\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vpid_to_list\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nport_close\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fport_command\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fport_connect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fport_control\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQports\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npre_loaded\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fprocess_flag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fprocess_info\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprocesses\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpurge_module\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bregister\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nregistered\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQround\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTself\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsetelement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQspawn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nspawn_link\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tspawn_opt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsplit_binary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nstatistics\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOterm_to_binary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQthrow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXtl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtrunc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtuple_to_list\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunlink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nunregister\NUL\NUL\NUL\NUL\NUL\NUL\NUL\awhereis\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL1(?:\\(|\\)|\\{|\\}|\\[|\\]|\\.|\\:|\\||\\|\\||;|\\,|\\?|->|\\#)\SOH\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL%\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKErlang\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULW\\b[a-z][_a-z@-Z0-9]*(?:(?=[^_a-z@-Z0-9])|$):\\b[a-z][_a-z@-Z0-9]*(?:(?=[^_a-z@-Z0-9])|$)\SOH\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL-\\b[a-z][_a-z@-Z0-9]*(?:(?=[^_a-z@-Z0-9])|$)\\(\SOH\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKErlang\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nisfunction\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL,\\b[_A-Z][_a-z@-Z0-9]*(?:(?=[^_a-z@-Z0-9])|$)\SOH\DC2\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKErlang\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tatomquote\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL+\\b[a-z][_a-z@-Z0-9]*(?:(?=[^_a-z@-Z0-9])|$)\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKErlang\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vstringquote\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"[0-9]+\\.[0-9]+(?:[eE][+-]?[0-9]+)?\SOH\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\\d+#[a-zA-Z0-9]+\SOH\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\\$\\S\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK[0-9]+\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tatomquote\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tatomquote\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKErlang\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3(?:(?:\\\\')?[^']*)*'\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKErlang\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAlerts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nisfunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nisfunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKErlang\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL+\\b[a-z][_a-z@-Z0-9]*(?:(?=[^_a-z@-Z0-9])|$)\SOH\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vstringquote\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vstringquote\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKErlang\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3(?:(?:\\\\\")?[^\"]*)*\"\SOH\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USBill Ross (bill@emailme.net.au)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLGPLv2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.erl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormal Text"
