{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for dot.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/dot.xml and 'make bootstrap'.
module Skylighting.Syntax.Dot (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for dot.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adot.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCommentML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCommentML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SOH*/\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAlerts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCommentSL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCommentSL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAlerts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDetectAll\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDetectAll\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adigraph\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTedge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsubgraph\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXURL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tarrowhead\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tarrowsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tarrowtail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abgcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcenter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nconstraint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdecorateP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndistortion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfillcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfontcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfontname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfontsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bheadclip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\theadlabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKheight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlabelangle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rlabeldistance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOlabelfontcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rlabelfontname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rlabelfontsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlayer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlayers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmargin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amclimit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKminlen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anodesep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anslimit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bordering\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vorientation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apagedir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vperipheries\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3port_label_distance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrank\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arankdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aranksep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQratio\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aregular\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrotate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsamehead\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsametail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQshape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tshapefile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsides\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTskew\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstyle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btailclip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttaillabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKweight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwidth\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX;=\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH->\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\b\\w+\\b\SOH\DC2\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SODetectComments\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vRegionCurly\NUL[\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRegionSquare\NUL(\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vRegionParen\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX)]}\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SODetectComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SODetectComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SOH//\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCommentSL\SOH/*\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCommentML\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDetectAll\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vRegionCurly\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vRegionCurly\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDetectAll\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vRegionParen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vRegionParen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL)\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDetectAll\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRegionSquare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRegionSquare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL]\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDetectAll\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SOH\\\\\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\\"\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$Postula Lo\195\175s (lois.postula@live.be)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.dot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal"
