{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for SQL.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/sql.xml and 'make bootstrap'.
module Skylighting.Syntax.Sql (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for SQL.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asql.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSql\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMMultiline C-style comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMMultiline C-style comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH*/\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\t\n %&(),;?[\\]{}\SOH\NUL\NUL\NUL\NUL\NUL\NUL\STXH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaccess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aaccount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXadd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQadmin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nadminister\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKadvise\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQafter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQagent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ball_rows\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ballocate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQalter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aanalyze\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tancillary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXany\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aarchive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\narchivelog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXasc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tassertion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tassociate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tattribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nattributes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQaudit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rauthenticated\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKauthid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rauthorization\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fautoallocate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nautoextend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tautomatic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbackup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbecome\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbefore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbegin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbehalf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abetween\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abinding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbitmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQblock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vblock_range\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbody\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTboth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbound\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tbroadcast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbtitle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vbuffer_pool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbuild\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbulk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXby\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcache\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcache_instances\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcancel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acascade\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcategory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\achained\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKchange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcheck\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncheckpoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchild\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKchoose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchunk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMclose_cached_open_cursors\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acluster\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcoalesce\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcolumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcolumn_value\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acolumns\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcommit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcommitted\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcompatibility\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acompile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcomplete\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcomposite_limit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcompress\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acompute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aconnect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fconnect_time\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bconsider\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nconsistent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bconstant\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nconstraint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vconstraints\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcontainer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acontext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontinue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcontrolfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcopy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcost\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcpu_per_call\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcpu_per_session\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcreate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNcreate_stored_outlines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcross\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcube\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acurrent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcursor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcycle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdangling\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdatabase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdatafile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdatafiles\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdba\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXddl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndeallocate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdebug\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adeclare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adefault\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndeferrable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdeferred\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adefiner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdegree\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdelete\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdemand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdesc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndetermines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndictionary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdimension\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adisable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fdisassociate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndisconnect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdiskgroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdismount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdistinct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdistributed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdomain\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdrop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adynamic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTeach\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQelsif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQempty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKenable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aenforce\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQentry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKescape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bestimate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKevents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexcept\NUL\NUL\NUL\NUL\NUL\NUL\NUL\texception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nexceptions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bexchange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\texcluding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\texclusive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aexecute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexists\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexpire\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aexplain\NUL\NUL\NUL\NUL\NUL\NUL\NUL\texplosion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aextends\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKextent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aextents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nexternally\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKfailed_login_attempts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfilter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfirst_rows\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aflagger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tflashback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQflush\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfollowing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQforce\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aforeign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfreelist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfreelists\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfresh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfrom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfunctions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tgenerated\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKglobal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vglobal_name\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bglobally\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQgrant\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQgroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgroups\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bhashkeys\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKhaving\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKheader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTheap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\thierarchy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThour\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nidentified\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nidentifier\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fidgenerators\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tidle_time\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\timmediate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tincluding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tincrement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vincremental\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQindex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aindexed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aindexes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tindextype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nindextypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tindicator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainitial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vinitialized\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tinitially\NUL\NUL\NUL\NUL\NUL\NUL\NUL\binitrans\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQinner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinsert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\binstance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tinstances\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainstead\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fintermediate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tintersect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTinto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ninvalidate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tisolation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIisolation_level\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjava\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjoin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTkeep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXkey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTkill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlayer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aleading\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTleft\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlevel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alibrary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlike\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlimit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlocal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alocator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlocked\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alogfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alogging\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNlogical_reads_per_call\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMlogical_reads_per_session\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlogoff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlogon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTloop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmanage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amanaged\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmanagement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmaster\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmaterialized\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmaxarchlogs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmaxdatafiles\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmaxextents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmaxinstances\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmaxlogfiles\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rmaxloghistory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rmaxlogmembers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amaxsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmaxtrans\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmaxvalue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmember\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmerge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmethod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nminextents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bminimize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aminimum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQminus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKminute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bminvalue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmodify\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmonitoring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmove\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmovement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SImts_dispatchers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmultiset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnamed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anatural\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKneeded\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnested\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SInested_table_id\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anetwork\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnever\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnew\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fnls_calendar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEnls_characterset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnls_comp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fnls_currency\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SInls_date_format\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1nls_date_language\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEnls_iso_currency\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnls_lang\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fnls_language\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNnls_numeric_characters\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnls_sort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1nls_special_chars\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rnls_territory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXno\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fnoarchivelog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anoaudit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anocache\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nnocompress\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anocycle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anoforce\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnologging\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nnomaxvalue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nnominimize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nnominvalue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fnomonitoring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anoorder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nnooverride\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nnoparallel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnorely\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vnoresetlogs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnoreverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnosegment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnosort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anothing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nnovalidate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnowait\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnulls\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQobjno\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vobjno_reuse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXoff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aoffline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXoid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\boidindex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXold\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKonline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTonly\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKopcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTopen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\boperator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aoptimal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOoptimizer_goal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKoption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQorder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\forganization\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQouter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aoutline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTover\NUL\NUL\NUL\NUL\NUL\NUL\NUL\boverflow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\boverlaps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apackage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpackages\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bparallel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nparameters\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKparent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpartition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOpartition_hash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIpartition_range\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npartitions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpassword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3password_grace_time\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2password_life_time\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2password_lock_time\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2password_reuse_max\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3password_reuse_time\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANpassword_verify_function\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apctfree\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vpctincrease\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpctthreshold\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apctused\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npctversion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apercent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpermanent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTplan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vplsql_debug\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEpost_transaction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bprebuilt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpreceding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aprepare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apresent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpreserve\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bprevious\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aprimary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQprior\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aprivate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vprivate_sga\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprivilege\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nprivileges\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprocedure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aprofile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpublic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpurge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQquery\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQqueue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQquota\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrandom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrba\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQreads\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arebuild\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1records_per_block\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arecover\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vrecoverable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brecovery\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arecycle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areduced\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nreferences\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vreferencing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arefresh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrely\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areplace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQreset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tresetlogs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKresize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aresolve\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bresolver\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bresource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brestrict\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nrestricted\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKresume\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\treturning\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQreuse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrevoke\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arewrite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQright\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrole\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQroles\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brollback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrollup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrownum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrows\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsample\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsavepoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTscan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOscan_instances\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKschema\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXscn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQscope\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsd_all\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsd_inhibit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asd_show\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tseg_block\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bseg_file\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asegment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKselect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vselectivity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsequence\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fserializable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vservererror\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asession\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNsession_cached_cursors\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1sessions_per_user\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQshare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKshared\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vshared_pool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKshrink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bshutdown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsingletask\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTskip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKskip_unusable_indexes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsnapshot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsome\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rspecification\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsplit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsql_trace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\astandby\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\astartup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstatement_id\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstatic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nstatistics\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTstop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\astorage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tstructure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsubmultiset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsubpartition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsubpartitions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsuccessful\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asummary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsupplemental\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asuspend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKswitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asynonym\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsys_op_bitvec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANsys_op_enforce_not_null$\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIsys_op_noexpand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOsys_op_ntcimg$\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsysdba\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asysoper\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsystem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntablespace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtablespace_no\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtabno\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btempfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttemporary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTthan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXthe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTthen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKthread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\athrough\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttime_zone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atimeout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtimezone_hour\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SItimezone_minute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btoplevel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtrace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atracing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btrailing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtransaction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftransitional\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atrigger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btriggers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btruncate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nunarchived\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aunbound\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tunbounded\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTundo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\auniform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQunion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunique\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tunlimited\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunlock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\runrecoverable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuntil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bunusable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunused\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vupd_indexes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tupdatable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKupdate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKuppper\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQusage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXuse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3use_stored_outlines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fuser_defined\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQusing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvalidate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvalidation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvalues\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTview\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwhen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bwhenever\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhere\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwith\NUL\NUL\NUL\NUL\NUL\NUL\NUL\awithout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwork\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwrite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\t\n %&(),;?[\\]{}\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX!=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX**\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH+\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH-\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX..\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH/\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX:=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH<\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX<=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX<>\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX=>\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH>\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX>=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX^=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX||\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX~=\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\t\n %&(),;?[\\]{}\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\210\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTacos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nadd_months\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQascii\NUL\NUL\NUL\NUL\NUL\NUL\NUL\basciistr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTasin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTatan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQatan2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXavg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tbfilename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nbin_to_num\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbitand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcardinality\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTceil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vchartorowid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXchr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcoalesce\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acollect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acompose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKconcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aconvert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcorr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcorr_k\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcorr_s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcosh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcovar_pop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncovar_samp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcume_dist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcurrent_date\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1current_timestamp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndbtimezone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdecode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdecompose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndense_rank\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdepth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQderef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdump\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nempty_blob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nempty_clob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nexistsnode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aextract\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fextractvalue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfirst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vfirst_value\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfloor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afrom_tz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgreatest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgroup_id\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgrouping\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgrouping_id\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bhextoraw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainitcap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQinstr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinstrb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blast_day\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlast_value\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlead\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQleast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alengthb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXln\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlnnvl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOlocaltimestamp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlower\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlpad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQltrim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmake_ref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmedian\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmonths_between\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnanvl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnchr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnew_time\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnext_day\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4nls_charset_decl_len\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOnls_charset_id\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEnls_charset_name\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vnls_initcap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnls_lower\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnls_upper\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anlssort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQntile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnullif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SInumtodsinterval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SInumtoyminterval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnvl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnvl2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bora_hash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nora_rowscn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpercent_rank\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIpercentile_cont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIpercentile_disc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpower\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rpowermultiset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSpowermultiset_by_cardinality\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npresentnnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpresentv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrank\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIratio_to_report\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brawtohex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\trawtonhex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breftohex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fregexp_instr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vregexp_like\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOregexp_replace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rregexp_substr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tregr_avgx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tregr_avgy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nregr_count\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOregr_intercept\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aregr_r2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nregr_slope\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bregr_sxx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bregr_sxy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bregr_syy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tremainder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQround\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nrow_number\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vrowidtochar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\frowidtonchar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrpad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrtrim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEscn_to_timestamp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIsessiontimezone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsinh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asoundex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsqrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3stats_binomial_test\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOstats_crosstab\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstats_f_test\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rstats_ks_test\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nstats_mode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rstats_mw_test\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3stats_one_way_anova\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2stats_t_test_indep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3stats_t_test_indepu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEstats_t_test_one\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3stats_t_test_paired\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOstats_wsr_test\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstddev\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nstddev_pop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vstddev_samp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsubstr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asubstrb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3sys_connect_by_path\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsys_context\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsys_dburigen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIsys_extract_utc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsys_guid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsys_typeid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsys_xmlagg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsys_xmlgen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asysdate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsystimestamp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtanh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEtimestamp_to_scn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEto_binary_double\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIto_binary_float\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ato_char\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ato_clob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ato_date\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rto_dsinterval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKto_lob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rto_multi_byte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bto_nchar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bto_nclob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tto_number\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOto_single_byte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fto_timestamp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIto_timestamp_tz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rto_yminterval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttranslate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtreat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtrunc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttz_offset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXuid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunistr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tupdatexml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQupper\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTuser\NUL\NUL\NUL\NUL\NUL\NUL\NUL\auserenv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvalue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avar_pop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvar_samp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvariance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fwidth_bucket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKxmlagg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fxmlcolattval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txmlconcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nxmlelement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txmlforest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vxmlsequence\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fxmltransform\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\t\n %&(),;?[\\]{}\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aanydata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nanydataset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aanytype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQarray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rbinary_double\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fbinary_float\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SObinary_integer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTblob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aboolean\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTchar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcharacter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTclob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXday\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdburitype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adecimal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTflob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vhttpuritype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\binterval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmlslabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmonth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnational\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnchar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnclob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anumeric\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnvarchar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKobject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vpls_integer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprecision\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXraw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTreal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrecord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrowid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsecond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsingle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsmallint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttimestamp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOurifactorytype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\auritype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKurowid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avarchar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvarchar2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvarray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avarying\NUL\NUL\NUL\NUL\NUL\NUL\NUL\axmltype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTyear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzone\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULO%(?:bulk_(?:exceptions|rowcount)|found|isopen|notfound|rowcount|rowtype|type)\\b\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOString literal\SOH--\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USSingleline PL/SQL-style comment\SOH/*\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMMultiline C-style comment\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrem\\b\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMSQL*Plus remark directive\NUL\"\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBUser-defined identifier\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n(:|&&?)\\w+\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX/$\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO@@?[^@ \\t\\r\\n]\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"SQL*Plus directive to include file\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"SQL*Plus directive to include file\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"SQL*Plus directive to include file\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMSQL*Plus remark directive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMSQL*Plus remark directive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USSingleline PL/SQL-style comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USSingleline PL/SQL-style comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOString literal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOString literal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\SOH\\'\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\f\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK&&?\\w+\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH''\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBUser-defined identifier\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBUser-defined identifier\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\"\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"Yury Lebedev (yurylebedev@mail.ru)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLGPL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.sql\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.SQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.ddl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.DDL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal"
