{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for Scheme.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/scheme.xml and 'make bootstrap'.
module Skylighting.Syntax.Scheme (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for Scheme.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nscheme.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDefault\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDefault\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r;+\\s*BEGIN.*$\SOH\EM\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v;+\\s*END.*$\SOH\EM\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT;.*$\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH#!\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMultiLineComment\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\t\n %&(),.;[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\210\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTacos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQangle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKappend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bapplymap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTasin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQassoc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTassq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTassv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTatan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbegin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bboolean?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcaaaar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcaaadr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcaaar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcaadar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcaaddr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcaadr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcaar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcadaar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcadadr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcadar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcaddar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcadddr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcaddr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcadr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RScall-with-current-continuation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4call-with-input-file\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKcall-with-output-file\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcall-with-values\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acall/cc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcdaaar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcdaadr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcdaar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcdadar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcdaddr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcdadr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcdar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcddaar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcddadr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcddar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcdddar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcddddr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcdddr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcddr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcdr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aceiling\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rchar->integer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEchar-alphabetic?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nchar-ci<=?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tchar-ci=?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nchar-ci>=?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tchar-ci>?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rchar-downcase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEchar-lower-case?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rchar-numeric?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vchar-ready?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vchar-upcase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEchar-upper-case?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEchar-whitespace?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\achar<=?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\achar<?c\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKchar=?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\achar>=?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKchar>?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchar?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEclose-input-port\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1close-output-port\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcomplex?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcons\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontinue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2current-input-port\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3current-output-port\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdenominator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adisplay\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fdynamic-wind\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\veof-object?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXeq?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKequal?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTeqv?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTeval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQeven?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOexact->inexact\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexact?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexpt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfloor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfor-each\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQforce\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgcd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bhar-ci<?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\timag-part\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOinexact->exact\NUL\NUL\NUL\NUL\NUL\NUL\NUL\binexact?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vinput-port?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rinteger->char\NUL\NUL\NUL\NUL\NUL\NUL\NUL\binteger?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBinteraction-environment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlambda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlcm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlet*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlet-syntax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKletrec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rletrec-syntax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\flist->string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blist-ref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlist-tail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlist?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTload\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmagnitude\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmake-polar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEmake-rectangular\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmake-string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmake-vector\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmember\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmemq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmemv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmodulo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnegative?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anewline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEnull-environment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnull?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOnumber->string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anumber?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnumerator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTodd?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIopen-input-file\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEopen-output-file\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\foutput-port?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpair?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpeek-char\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQport?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpositive?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nprocedure?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bquotient\NUL\NUL\NUL\NUL\NUL\NUL\NUL\trational?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vrationalize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tread-char\NUL\NUL\NUL\NUL\NUL\NUL\NUL\treal-part\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQreal?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tremainder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQround\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMscheme-report-environment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bset-car!\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bset-cdr!\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsqrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstring->list\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOstring->number\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOstring->symbol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rstring-append\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstring-ci<=?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vstring-ci<?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vstring-ci=?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstring-ci>=?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vstring-ci>?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vstring-copy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstring-fill!\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rstring-length\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nstring-ref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vstring-set!\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tstring<=?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bstring<?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bstring=?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tstring>=?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bstring>?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\astring?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsubstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOsymbol->string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asymbol?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsyntax-rules\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtranscript-off\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtranscript-on\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btruncate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvalues\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvector\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANvector->listlist->vector\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvector-fill!\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvector-length\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvector-ref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vvector-set!\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avector?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4with-input-from-file\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3with-output-to-file\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwrite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nwrite-char\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzero?\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\t\n %&(),.;[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX*)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX*,*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH+\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH-\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH/\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH<\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX<=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX=>\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH>\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX>=\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\t\n %&(),.;[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdefine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adefine*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOdefine*-public\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIdefine-accessor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fdefine-class\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOdefine-generic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fdefine-macro\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdefine-method\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdefine-module\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOdefine-private\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdefine-public\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2define-reader-ctor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdefine-syntax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3define-syntax-macro\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdefined?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdefmacro\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdefmacro*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEdefmacro*-public\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rfunction_decl\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\t\n %&(),.;[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\ack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v#\\backspace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\bel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT#\\bs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\can\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT#\\cr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\dc1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\dc2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\dc3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\dc4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\dle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT#\\em\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\enq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\eot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\esc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\etb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\etx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT#\\fs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT#\\gs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT#\\ht\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\nak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t#\\newline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT#\\nl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT#\\np\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\nul\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK#\\null\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK#\\page\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b#\\return\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT#\\rs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT#\\si\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT#\\so\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\soh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT#\\sp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a#\\space\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\stx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\sub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\syn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\tab\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT#\\us\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT#\\vt\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT#\\\\.\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t#[bodxei]\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSpecialNumber\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#[tf]\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLevel1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLevel0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLevel0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL(\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLevel1\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDefault\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLevel1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLevel1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL(\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLevel2\NUL)\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDefault\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLevel2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLevel2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL(\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLevel3\NUL)\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDefault\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLevel3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLevel3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL(\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLevel4\NUL)\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDefault\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLevel4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLevel4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL(\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLevel5\NUL)\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDefault\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLevel5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLevel5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL(\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLevel6\NUL)\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDefault\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLevel6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLevel6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL(\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLevel1\NUL)\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDefault\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMultiLineComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMultiLineComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK!#\\s*$\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSpecialNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSpecialNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\d*(\\.\\d+)?\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\t\n %&(),.;[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\ack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v#\\backspace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\bel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT#\\bs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\can\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT#\\cr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\dc1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\dc2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\dc3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\dc4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\dle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT#\\em\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\enq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\eot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\esc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\etb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\etx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT#\\fs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT#\\gs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT#\\ht\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\nak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t#\\newline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT#\\nl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT#\\np\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\nul\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK#\\null\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK#\\page\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b#\\return\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT#\\rs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT#\\si\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT#\\so\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\soh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT#\\sp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a#\\space\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\stx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\sub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\syn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ#\\tab\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT#\\us\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT#\\vt\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT#\\\\.\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\\"\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\\\\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rfunction_decl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rfunction_decl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\\s*[A-Za-z0-9-+\\<\\>//\\*]*\\s*\SOH\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSDominik Haumann (dhdev@gmx.de)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aLGPLv2+\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.scm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.ss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b*.scheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a*.guile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLevel0"
