{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for PostScript.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/postscript.xml and 'make bootstrap'.
module Skylighting.Syntax.Postscript (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for PostScript.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPostScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOpostscript.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPostscript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPostScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKHeader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKHeader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPostScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPostScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\SOH\137\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXadd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQaload\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fanchorsearch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXarc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTarcn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTarct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQarcto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQarray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rascii85decode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rascii85encode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOasciihexdecode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOasciihexencode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQashow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKastore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTatan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nawidthshow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nbanddevice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbegin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbind\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbitshift\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SObytesavailable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcachestatus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOccittfaxdecode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOccittfaxencode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aceiling\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcharpath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tciebaseda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vciebasedabc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vciebaseddef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fciebaseddefg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcleardictstack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcleartomark\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTclip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bclippath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tclosefile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tclosepath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncolorimage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKconcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fconcatmatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcondition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcopy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcopypage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcountdictstack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcountexecstack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcounttomark\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acourier\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcourier-bold\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3courier-boldoblique\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcourier-oblique\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcshow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNcurrentblackgeneration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2currentcacheparams\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcurrentcmykcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcurrentcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKcurrentcolorrendering\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2currentcolorscreen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1currentcolorspace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4currentcolortransfer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcurrentcontext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcurrentdash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcurrentdevparams\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcurrentdict\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcurrentfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcurrentflat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcurrentfont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcurrentglobal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcurrentgray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcurrentgstate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcurrenthalftone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4currenthalftonephase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcurrenthsbcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcurrentlinecap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcurrentlinejoin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcurrentlinewidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcurrentmatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1currentmiterlimit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3currentobjectformat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcurrentoverprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcurrentpacking\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1currentpagedevice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcurrentpoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcurrentrgbcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcurrentscreen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcurrentshared\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3currentstrokeadjust\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3currentsystemparams\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcurrenttransfer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANcurrentundercolorremoval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1currentuserparams\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acurveto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcvi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcvlit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcvn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcvr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcvrs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcvs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcvx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdctdecode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdctencode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdefaultmatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndefinefont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOdefineresource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOdefineusername\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEdefineuserobject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndeletefile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdetach\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndevicecmyk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndevicegray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndeviceinfo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adevicen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdevicergb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdict\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdictstack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndtransform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTecho\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKeoclip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKeofill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\neoviewclip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\terasepage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\terrordict\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bexecform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\texecstack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOexecuserobject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vexecuteonly\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOfilenameforall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ffileposition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfilter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ffindencoding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfindfont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ffindresource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vflattenpath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfloor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQflush\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tflushfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rfontdirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKforall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfork\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vframedevice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgcheck\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgetinterval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nglobaldict\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3globalfontdirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tglyphshow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgrestore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgrestoreall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQgsave\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgstate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXgt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vhandleerror\NUL\NUL\NUL\NUL\NUL\NUL\NUL\thelvetica\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOhelvetica-bold\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKhelvetica-boldoblique\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1helvetica-oblique\NUL\NUL\NUL\NUL\NUL\NUL\NUL\videntmatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTidiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vidtransform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKifelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQimage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\timagemask\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQindex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aindexed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bineofill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinfill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\binitclip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\finitgraphics\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ninitmatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\finitviewclip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\binstroke\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tinueofill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainufill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tinustroke\NUL\NUL\NUL\NUL\NUL\NUL\NUL\finvertmatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1isolatin1encoding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nitransform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjoin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQknown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQkshow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rlanguagelevel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlineto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXln\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTload\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTloop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXlt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlzwdecode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlzwencode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmakefont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmakepattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmark\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmaxlength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amonitor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmoveto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmul\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXne\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXneg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anewpath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnoaccess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnotify\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nnulldevice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nnullencode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vpackedarray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpathbbox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npathforall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vprintobject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aproduct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpstack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vputinterval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTquit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrcheck\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brcurveto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rreadhexstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breadline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breadonly\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nreadstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brealtime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brectclip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brectfill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nrectstroke\NUL\NUL\NUL\NUL\NUL\NUL\NUL\frectviewclip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nrenamefile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vrenderbands\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrepeat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tresetfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOresourceforall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOresourcestatus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arestore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vreversepath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brevision\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arlineto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\armoveto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTroll\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brootfont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrotate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQround\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrrand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrun\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIrunlengthdecode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIrunlengthencode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsave\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQscale\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tscalefont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKscheck\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsearch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nselectfont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nseparation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fserialnumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asetbbox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2setblackgeneration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOsetcachedevice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIsetcachedevice2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsetcachelimit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOsetcacheparams\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsetcharwidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsetcmykcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsetcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1setcolorrendering\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOsetcolorscreen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsetcolorspace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEsetcolortransfer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asetdash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsetdevparams\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIsetfileposition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asetflat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asetfont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsetglobal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asetgray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsetgstate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsethalftone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEsethalftonephase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsethsbcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsetlinecap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsetlinejoin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsetlinewidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsetmatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsetmiterlimit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIsetobjectformat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsetoverprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsetpacking\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsetpagedevice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsetpattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsetrgbcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsetscreen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsetshared\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIsetstrokeadjust\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIsetsystemparams\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsettransfer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIsetucacheparams\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4setundercolorremoval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsetuserparams\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOsetvmthreshold\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nshareddict\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3sharedfontdirectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTshow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bshowpage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsqrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsrand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEstandardencoding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bstartjob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstatus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nstatusdict\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTstop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\astopped\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vstringwidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstroke\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nstrokepath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsubfiledecode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsymbol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsystemdict\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntimes-bold\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEtimes-bolditalic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftimes-italic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtimes-roman\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtoken\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttransform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttranslate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btruncate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\auappend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKucache\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fucachestatus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aueofill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQufill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQundef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fundefinefont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEundefineresource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2undefineuserobject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQupath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\buserdict\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vuserobjects\NUL\NUL\NUL\NUL\NUL\NUL\NUL\busertime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\austroke\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vustrokepath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aversion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bviewclip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fviewclippath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvmreclaim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmstatus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwait\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKwcheck\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhere\NUL\NUL\NUL\NUL\NUL\NUL\NUL\twidthshow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwrite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOwritehexstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vwriteobject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vwritestring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fwtranslation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKxcheck\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXxor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxshow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKxyshow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQyield\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQyshow\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH%!\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPostScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKHeader\NUL%\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPostScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\t\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPostScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\\/{1,2}[^\\s\\(\\)\\{\\}\\[\\]%/]*\SOH\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPostScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL)\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.ai\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.eps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal"
