{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for Python.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/python.xml and 'make bootstrap'.
module Skylighting.Syntax.Python (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for Python.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npython.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL!\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI#CheckForString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI#CheckForString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2CheckForStringNext\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2CheckForStringNext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2CheckForStringNext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2CheckForStringNext\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOStringVariants\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICommentVariants\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICommentVariants\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQu?'''\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLETriple A-comment\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQu?\"\"\"\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLETriple Q-comment\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXu?'\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESingle A-comment\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXu?\"\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESingle Q-comment\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v(u?r|ru)'''\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLETriple A-comment\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v(u?r|ru)\"\"\"\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLETriple Q-comment\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t(u?r|ru)'\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESingle A-comment\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t(u?r|ru)\"\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESingle Q-comment\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDictionary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDictionary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOStringVariants\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fHash comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fHash comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAlerts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tModelines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTList\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTList\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL]\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOStringVariants\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !#%&'()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfrom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKimport\v\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !#%&'()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKglobal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlambda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnonlocal\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !#%&'()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXor\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !#%&'()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKassert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQasync\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQawait\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontinue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexcept\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afinally\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQraise\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwith\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQyield\DC3\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !#%&'()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NULS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n__import__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXany\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQapply\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQascii\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nbasestring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tbytearray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbytes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcallable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXchr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vclassmethod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcmp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcoerce\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acompile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomplex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adelattr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdict\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdivmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tenumerate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTeval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bexecfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfilter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKformat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfrozenset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agetattr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aglobals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ahasattr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThelp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXhex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQinput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKintern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nisinstance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nissubclass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTiter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlocals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmemoryview\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKobject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXoct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTopen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bproperty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\traw_input\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreduce\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreload\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrepr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breversed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQround\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asetattr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQslice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsorted\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstaticmethod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXstr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsuper\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtuple\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunichr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aunicode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTvars\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKxrange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXzip\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !#%&'()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bEllipsis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTNone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SONotImplemented\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTrue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t__debug__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__file__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__name__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTself\DC2\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !#%&'()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSIGNAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSLOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aconnect\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !#%&'()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NULA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIArithmeticError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAssertionError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAttributeError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rBaseException\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIBlockingIOError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIBrokenPipeError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vBufferError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fBytesWarning\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ChildProcessError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNConnectionAbortedError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIConnectionError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNConnectionRefusedError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ConnectionResetError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2DeprecationWarning\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bEOFError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEEnvironmentError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tException\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIFileExistsError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1FileNotFoundError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2FloatingPointError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rFutureWarning\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGeneratorExit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aIOError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vImportError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rImportWarning\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIndentationError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nIndexError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEInterruptedError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1IsADirectoryError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bKeyError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1KeyboardInterrupt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vLookupError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMemoryError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tNameError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2NotADirectoryError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3NotImplementedError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOSError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rOverflowError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMPendingDeprecationWarning\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIPermissionError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ProcessLookupError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOReferenceError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIResourceWarning\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRuntimeError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORuntimeWarning\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rStandardError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rStopIteration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSyntaxError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSyntaxWarning\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSystemError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSystemExit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTabError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTimeoutError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tTypeError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1UnboundLocalError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2UnicodeDecodeError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2UnicodeEncodeError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fUnicodeError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKUnicodeTranslateError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOUnicodeWarning\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vUserWarning\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nValueError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aWarning\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fWindowsError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ZeroDivisionError\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !#%&'()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NULb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__abs__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__add__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n__aenter__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t__aexit__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t__aiter__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__and__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t__anext__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t__await__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t__bytes__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__call__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__cmp__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n__coerce__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v__complex__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f__contains__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__del__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v__delattr__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n__delete__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v__delitem__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f__delslice__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__dir__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__div__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n__divmod__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t__enter__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK__eq__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__exit__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t__float__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f__floordiv__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n__format__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK__ge__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__get__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v__getattr__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE__getattribute__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v__getitem__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f__getslice__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK__gt__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__hash__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__hex__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__iadd__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__iand__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__idiv__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r__ifloordiv__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v__ilshift__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__imod__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__imul__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t__index__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__init__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__int__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n__invert__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__ior__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__ipow__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v__irshift__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__isub__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__iter__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f__itruediv__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__ixor__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK__le__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__len__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__long__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n__lshift__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK__lt__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__mod__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__mul__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK__ne__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__neg__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__new__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__next__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v__nonzero__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__oct__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK__or__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__pos__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__pow__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__radd__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__rand__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__rcmp__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__rdiv__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v__rdivmod__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__repr__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f__reversed__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r__rfloordiv__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v__rlshift__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__rmod__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__rmul__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__ror__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__rpow__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v__rrshift__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n__rshift__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__rsub__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f__rtruediv__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__rxor__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__set__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v__setattr__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v__setitem__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f__setslice__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__str__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__sub__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v__truediv__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v__unicode__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__xor__\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EM[a-zA-Z_][a-zA-Z_0-9]{2,}\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL] ((([0-9]*\\.[0-9]+|[0-9]+\\.)|([0-9]+|([0-9]*\\.[0-9]+|[0-9]+\\.))[eE](\\+|-)?[0-9]+)|[0-9]+)[jJ]\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDictionary\NUL[\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTList\NUL(\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQTuple\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICommentVariants\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fHash comment\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOStringVariants\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EM@[_a-zA-Z][\\._a-zA-Z0-9]*\SOH\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2+*/%\\|=;\\!<>!^&~-@\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORaw A-F-String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORaw A-F-String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\f\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3stringinterpolation\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI#CheckForString\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRaw A-string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRaw A-string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\f\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstringformat\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI#CheckForString\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORaw Q-F-String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORaw Q-F-String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\f\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3stringinterpolation\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI#CheckForString\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRaw Q-string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRaw Q-string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\f\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstringformat\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI#CheckForString\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKRaw Triple A-F-String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKRaw Triple A-F-String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\f\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3stringinterpolation\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX'''\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI#CheckForString\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Raw Triple A-string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Raw Triple A-string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\f\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstringformat\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX'''\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI#CheckForString\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKRaw Triple Q-F-String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKRaw Triple Q-F-String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\f\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3stringinterpolation\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\"\"\"\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI#CheckForString\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Raw Triple Q-string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Raw Triple Q-string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\f\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstringformat\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\"\"\"\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI#CheckForString\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Single A-F-String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Single A-F-String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstringescape\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3stringinterpolation\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI#CheckForString\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESingle A-comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESingle A-comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\f\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rAlerts_indent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISingle A-string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISingle A-string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstringescape\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstringformat\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI#CheckForString\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Single Q-F-String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Single Q-F-String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstringescape\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3stringinterpolation\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI#CheckForString\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESingle Q-comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESingle Q-comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\f\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rAlerts_indent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISingle Q-string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISingle Q-string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstringescape\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstringformat\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI#CheckForString\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4String Interpolation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4String Interpolation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\\\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULI(![rs])?(:([^}]?[<>=^])?[ +-]?#?0?[0-9]*(\\.[0-9]+)?[bcdeEfFgGnosxX%]?)?\\}\SOH\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOStringVariants\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOStringVariants\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQu?'''\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITriple A-string\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQu?\"\"\"\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITriple Q-string\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXu?'\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISingle A-string\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXu?\"\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISingle Q-string\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v(u?r|ru)'''\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Raw Triple A-string\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v(u?r|ru)\"\"\"\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Raw Triple Q-string\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t(u?r|ru)'\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRaw A-string\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t(u?r|ru)\"\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRaw Q-string\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTf'''\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Triple A-F-String\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTf\"\"\"\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Triple Q-F-String\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXf'\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Single A-F-String\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXf\"\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Single Q-F-String\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n(fr|rf)'''\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKRaw Triple A-F-String\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n(fr|rf)\"\"\"\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKRaw Triple Q-F-String\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b(fr|rf)'\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORaw A-F-String\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b(fr|rf)\"\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORaw Q-F-String\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Triple A-F-String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Triple A-F-String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstringescape\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3stringinterpolation\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX'''\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI#CheckForString\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLETriple A-comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLETriple A-comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX'''\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rAlerts_indent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITriple A-string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITriple A-string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstringescape\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstringformat\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX'''\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI#CheckForString\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Triple Q-F-String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Triple Q-F-String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstringescape\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3stringinterpolation\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\"\"\"\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI#CheckForString\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLETriple Q-comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLETriple Q-comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\r\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\"\"\"\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rAlerts_indent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITriple Q-string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITriple Q-string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstringescape\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstringformat\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\"\"\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI#CheckForString\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQTuple\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQTuple\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOStringVariants\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstringescape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstringescape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\\\\[\\\\'\"abfnrtv]\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\\\\[0-7]{1,3}\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\\\\x[0-9A-Fa-f]{2}\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\\\\u[0-9A-Fa-f]{4}\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\\\\U[0-9A-Fa-f]{8}\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\\\\N\\{[a-zA-Z0-9\\- ]+\\}\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstringformat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstringformat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULk%((\\([a-zA-Z0-9_]+\\))?[#0\\- +]?([1-9][0-9]*|\\*)?(\\.([1-9][0-9]*|\\*))?[hlL]?[crsdiouxXeEfFgG%]|prog|default)\SOH\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\130\\{(([a-zA-Z0-9_]+|[0-9]+)(\\.[a-zA-Z0-9_]+|\\[[^ \\]]+\\])*)?(![rs])?(:([^}]?[<>=^])?[ +-]?#?0?[0-9]*(\\.[0-9]+)?[bcdeEfFgGnosxX%]?)?\\}\SOH\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH{{\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH}}\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3stringinterpolation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3stringinterpolation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SOH{{\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4String Interpolation\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMichael Bueker\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.py\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.pyw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSConstruct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSConscript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal"
