{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for MIPS Assembler.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/mips.xml and 'make bootstrap'.
module Skylighting.Syntax.Mips (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for MIPS Assembler.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMIPS Assembler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmips.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTMips\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMIPS Assembler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !%&()*+,-/:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NULu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQabs.d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQabs.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXadd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQadd.d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQadd.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTaddi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQaddiu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTaddu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTandi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbc0f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbc0t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbc1f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbc1t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbc2f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbc2t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbc3f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbc3t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbgez\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbgezal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbgtz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTblez\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbltz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbltzal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbne\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKc.eq.d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKc.eq.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKc.le.d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKc.le.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKc.lt.d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKc.lt.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ac.ole.d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ac.ole.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ac.olt.d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ac.olt.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ac.seq.d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ac.seq.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ac.ueq.d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ac.ueq.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ac.ule.d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ac.ule.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ac.ult.d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ac.ult.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKc.un.d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKc.un.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acvt.d.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acvt.d.w\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acvt.s.d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acvt.s.w\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acvt.w.d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acvt.w.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdiv.d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdiv.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHj\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjalr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXjr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXlb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlbu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXlh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlhu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlui\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXlw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlwc0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlwc1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlwc2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlwc3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlwl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlwr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmfc0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmfc1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmfc2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmfc3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmfhi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmflo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmtc0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmtc1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmtc2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmtc3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmthi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmtlo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmul.d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmul.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmult\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmultu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXori\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrfe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXsb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsll\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsllv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXslt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTslti\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsltiu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsra\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsrav\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsrl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsrlv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsub.d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsub.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsubu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXsw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTswc0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTswc1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTswc2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTswc3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTswcl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXswl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXswr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asyscall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXxor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxori\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !%&()*+,-/:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL9\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbeqz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbgeu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbgt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbgtu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbleu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXblt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbltu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbnez\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdivu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXl.d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXl.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXla\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXli\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTli.d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTli.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmfc0.d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmfc1.d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmfc2.d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmfc3.d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmov.d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmov.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmove\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmul\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmulo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmulou\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXneg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQneg.d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQneg.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnegu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTremu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXror\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXs.d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXs.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXsd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXseq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsgeu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsgt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsgtu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsleu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsne\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXulh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTulhu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXulw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXush\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXusw\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !%&()*+,-/:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL+\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX$0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX$1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$10\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$11\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$12\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$13\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$14\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$15\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$17\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$18\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$19\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX$2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$20\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$21\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$22\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$23\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$24\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$25\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$26\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$27\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$28\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$29\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX$3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$30\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$31\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX$4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX$5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX$6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX$7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX$8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX$9\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$t0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$t1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$t2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$t3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$t4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$t5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$t6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$t7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$t8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$t9\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ$zero\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !%&()*+,-/:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$a0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$a1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$a2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$a3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$at\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$fp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$gp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$k0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$k1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$ra\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$s0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$s1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$s2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$s3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$s4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$s5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$s6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$s7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$sp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$v0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$v1\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !%&()*+,-/:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL \NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$f0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$f1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$f10\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$f11\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$f12\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$f13\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$f14\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$f15\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$f16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$f17\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$f18\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$f19\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$f2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$f20\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$f21\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$f22\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$f23\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$f24\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$f25\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$f26\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$f27\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$f28\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$f29\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$f3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$f30\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$f31\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$f4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$f5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$f6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$f7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$f8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$f9\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !%&()*+,-/:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.data\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.kdata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.ktext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.text\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !%&()*+,-/:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.align\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.ascii\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.asciiz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.byte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.double\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.extern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.float\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.globl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.half\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.sdata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT.set\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.space\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ.word\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f#\\s*BEGIN.*$\SOH\EM\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n#\\s*END.*$\SOH\EM\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT#.*$\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t[\\w_\\.]+:\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMIPS Assembler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\t\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMIPS Assembler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\\\\.\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSDominik Haumann (dhdev@gmx.de)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLGPL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX*.s\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnormal"
