{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for Rust.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/rust.xml and 'make bootstrap'.
module Skylighting.Syntax.Rust (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for Rust.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRust\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brust.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRust\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tAttribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tAttribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRust\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL]\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRust\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCharEscape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCharEscape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRust\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnrt\\'\"\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIx[0-9a-fA-F]{2}\SOH\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKu\\{[0-9a-fA-F]{1,6}\\}\SOH\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIu[0-9a-fA-F]{4}\SOH\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIU[0-9a-fA-F]{8}\SOH\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.\SOH\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCharacter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCharacter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRust\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\\\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRust\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCharEscape\NUL'\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommentar 1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommentar 1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRust\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommentar 2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommentar 2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRust\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH/*\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRust\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommentar 2\SOH*/\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRust\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL<\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRust\NUL\NUL\NUL\NUL\NUL\NUL\NUL \DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXfn\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRust\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFunction\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtype\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRust\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTType\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSelf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\babstract\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aalignof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbecome\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQconst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontinue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcrate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTenum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKextern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfinal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTimpl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTloop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmacro\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmove\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmut\NUL\NUL\NUL\NUL\NUL\NUL\NUL\boffsetof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\boverride\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpriv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTproc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTself\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsizeof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstatic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstruct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsuper\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtrait\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtypeof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunsafe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aunsized\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXuse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avirtual\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhere\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQyield\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXBox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKResult\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSelf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXVec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTchar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXf32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXf64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXi16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXi32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXi64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXi8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQisize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXstr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXu16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXu32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXu64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXu8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTuint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQusize\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aAsSlice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCharExt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQClone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCopy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQDebug\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDecodable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDefault\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDisplay\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3DoubleEndedIterator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDrop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tEncodable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXEq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKExtend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXFn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFnMut\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKFnOnce\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rFromPrimitive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTHash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bIterator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vIteratorExt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tMutPtrExt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXOrd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPartialEq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPartialOrd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPtrExt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQSized\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSliceConcatExt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSliceExt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXStr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKStrExt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSync\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bToString\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDIR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTFILE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKc_char\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bc_double\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ac_float\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQc_int\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKc_long\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nc_longlong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ac_schar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ac_short\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ac_uchar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKc_uint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ac_ulong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vc_ulonglong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bc_ushort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKc_void\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aclock_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdev_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdirent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfpos_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQino_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bintptr_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmode_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQoff_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpid_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tptrdiff_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsize_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\assize_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtime_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tuintptr_t\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTself\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCons\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXErr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aFailure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTNone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXOk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSome\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSuccess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrue\ENQ\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBUFSIZ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXEOF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fEXIT_FAILURE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fEXIT_SUCCESS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFILENAME_MAX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFOPEN_MAX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTF_OK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bL_tmpnam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bO_APPEND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aO_CREAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKO_EXCL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bO_RDONLY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKO_RDWR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aO_TRUNC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bO_WRONLY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bRAND_MAX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTR_OK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSEEK_CUR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSEEK_END\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSEEK_SET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSTDERR_FILENO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSTDIN_FILENO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSTDOUT_FILENO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aS_IEXEC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aS_IFBLK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aS_IFCHR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aS_IFDIR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aS_IFIFO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKS_IFMT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aS_IFREG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aS_IREAD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aS_IRUSR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aS_IRWXU\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bS_IWRITE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aS_IWUSR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aS_IXUSR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aTMP_MAX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTW_OK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTX_OK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK_IOFBF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK_IOLBF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK_IONBF\ENQ\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH//\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRust\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommentar 1\SOH/*\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRust\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommentar 2\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL#0x[0-9a-fA-F_]+([iu](8|16|32|64)?)?\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS0o[0-7_]+([iu](8|16|32|64)?)?\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS0b[0-1_]+([iu](8|16|32|64)?)?\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL4[0-9][0-9_]*\\.[0-9_]*([eE][+-]?[0-9_]+)?(f32|f64|f)?\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL [0-9][0-9_]*([iu](8|16|32|64)?)?\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH#[\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRust\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tAttribute\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX#![\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRust\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tAttribute\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN[a-zA-Z_][a-zA-Z_0-9]*::\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB[a-zA-Z_][a-zA-Z_0-9]*!\SOH\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS'[a-zA-Z_][a-zA-Z_0-9]*(?!')\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHr\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRust\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRawString\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTr##\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRust\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nRawHashed2\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXr#\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRust\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nRawHashed1\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRust\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL'\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRust\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCharacter\NUL[\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL]\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nRawHashed1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nRawHashed1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRust\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\"#\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nRawHashed2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nRawHashed2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRust\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\"##\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRawString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRawString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRust\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRust\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\\\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRust\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCharEscape\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTType\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTType\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRust\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL=\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL<\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL;\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCThe Rust Project Developers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.rs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal"
